class BatchContainersController < ApplicationController
  model_data_store(BatchContainer)

  def before_set_target
    @models.eager_load(:batch_container_components)
  end

  def before_set_targets
    @models.eager_load(:batch_container_components)
  end

  def save
    data = JSON.parse(params["batch"], symbolize_names: true)
    is_new = data[:id] == -1

    @model = if is_new
               BatchContainer.new(batch_process_id: data[:batch_process_id])
             else
               BatchContainer.eager_load(:batch_container_components).find_by_id(data[:id])
             end
    return render json: {error: "Batch does not exist."}, status: 404 if @model.nil?

    # Manually force the update_at time to change so that the cached model is cleared. Note: touch does not seem to work with poly relationships?
    @model.assign_attributes({name: data[:name], updated_at: Time.zone.now})


    @model.update_components(data[:components], params)

    if @model.save
      ActionCable.server.broadcast "everything", {
        model: JSON.parse(@model.to_json),
        class: @model.broadcast_class_name,
        action: is_new ? :create : :update,
        timestamp: Time.now.to_i
      }
      render json: @model, status: :ok, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end
end
