class BatchWorkstationsController < RxModule::WorkstationController

  def self.set_target_before
    super + [:job_call, :current_batch, :save_current_batch, :create_external_batch, :batch_save_response, :set_state]
  end

  model_data_store(BatchWorkstation)

  def create
    @model = BatchWorkstation.new(model_params)
    @model.build_batch_workstation_current_batch({ data: nil })

    if @model.save
      render json: @model, status: :created, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def current_batch
    render json: @model.batch_workstation_current_batch.data
  end

  def save_current_batch
    params = save_current_batch_params
    save_data = nil
    save_data = params[:data].to_json if !params[:data].nil?

    @model.batch_workstation_current_batch.update(data: save_data)

    if @model.batch_workstation_current_batch.save
      render json: {status: 'save successful' }, status: :ok, location: @model
    else
      render json: @model.batch_workstation_current_batch.errors, status: :unprocessable_entity
    end
  end

  def job_call
    params = job_call_params

    data = @model.fetch_tags_for_job(params[:number])

    if data[:error]
      if data[:error][:jobDoesNotExist]
        render json: { error: data[:error][:message], jobNotFound: true }, status: :not_found
      else
        render json: { error: data[:error][:message] }, status: :unprocessable_entity
      end
    else
      render json: data[:tags], status: :ok
    end
  end

  def create_external_batch
    #TODO: add  batch validation ?
    resp = RxModule::Communicator.call_module_method(
      "rx_data",
      "/api/batches",
      :post,
      {
        workstationId: @model.id,
        batch: create_batch_params
      }
    )
    @model.update!(state: 'saving', last_save_response: nil)
    render json: resp, status: :ok
  rescue => err
    Rails::logger.error("Failed to submit batch to rx-data: #{err}")
    render json: {error: err}, status: :internal_server_error
  end

  def batch_save_response
    if params[:success]
      @model.update!(state: 'completed', last_save_response: "{ \"rx_data_batch_id\": #{params[:batch_id]} }")
    else
      @model.update!(state: 'error', last_save_response: params[:error])
    end
    render json: {}, status: :ok
  end

  def set_state
    @model.update!(state: params[:state], last_save_response: nil) if params[:state]
    render json: {status: @model.state}, status: :ok
  end

  private

  def model_params
    params.require(:batch_workstation).permit(:name, :batch_process_id, :data_source, :external_dcs_id, :tags, batch_container_ids:[])
  end

  def set_state_params
    params.permit(:state)
  end

  def create_batch_params
    params.require(:batch).permit(:processCode, :batchId, :batchData => {})
  end

  def job_call_params
    params.require(:job).permit(:number)
  end

  def save_current_batch_params
    params.require(:current_batch).permit(:data => {})
  end
end