import * as React from 'react';
import {Layout, Providers} from '@rx-suite/ui';
import './stores';
import {RxAppModel, RxAppStore, RxModuleInfoStore} from '@rx-suite/stores';
import {getRoutes, routes} from "./routes";
import 'react-table/react-table.css';
import 'react-table-hoc-fixed-columns/lib/styles.css'
import {observer} from "mobx-react-lite";
import {subscribe} from "@rx-suite/data";
import {LinearProgress} from "@material-ui/core";
import {t} from "@lingui/macro";

subscribe();

export default observer(() => {
    const [ messages, setMessages ] = React.useState<any>(null);
    const model = RxAppStore.selectedModel as RxAppModel;
    let version = "";
    React.useEffect(() => {
        const getMessages = async () => {
            const compiledMessages = await import(`../../../locales/${model.language}/messages.mjs`);
            setMessages(compiledMessages.messages);
        }
        if (model) {
            model.setTitleBase(t`Rx-Batching`)
        }
        getMessages();
    }, [model]);
    if(RxModuleInfoStore.selectedModel) {
        version = RxModuleInfoStore.selectedModel.version as string;
    }
    if(!model || !messages) {
        return <LinearProgress />
    }
    return(
        <Providers theme={model.theme} language={model.language} messages={messages}>
            <Layout logoSrc={"/api/rx_module/logo"} routes={getRoutes()} version={version}/>
        </Providers>
    )
});


