import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {ArDomeSectorPositionRenderer} from "../../objects/canvas_renderer/ar_coating/ArDomeSectorPositionRenderer";

export type ArSectorDomePositionCanvasProps = {
    numberOfSectors:  number
    highlightedSector: number
};

const useStyles = makeStyles({
    canvas: {
        touchAction: 'none',
        outline: 'none',
        width: '100%',
        height: '100%',
    }
});

export const ArSectorDomePositionCanvas: React.FunctionComponent<ArSectorDomePositionCanvasProps> = observer(({numberOfSectors, highlightedSector}) => {
    const size = 75;

    const classes = useStyles();
    const renderer = new ArDomeSectorPositionRenderer(size, numberOfSectors, highlightedSector);

    const setCanvasRef = React.useCallback((e) => {
        if (!renderer) return;
        renderer.setCanvasRef(e);
        renderer.draw();
    }, [renderer]);

    return (
        <React.Fragment>
            <canvas
                width={size}
                height={size}
                className={classes.canvas}
                ref={setCanvasRef}
            />
        </React.Fragment>
    )
});