import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, createStyles, Grid, makeStyles, Theme} from "@material-ui/core";
import {SerializedSectorDatum} from "../../../objects/ar_coating/SectorDatum";
import {BatchContainerViewCanvas} from "../../batch_container/BatchContainerViewCanvas";
import {BatchContainerModel, BatchContainerStore} from "../../../stores/BatchContainerStore";
import {ArSectorSummaryInfoCard} from "./ArSectorSummaryInfoCard";
import {ArSectorSummaryLensTable} from "./ArSectorSummaryLensTable";
import classNames from "classnames";

interface ArSectorSummaryProps {
    data: SerializedSectorDatum;
    totalSectorCount: number;
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        sectionWrapper: {
            padding: theme.spacing(2)
        },
        sectorWrap: {
            height: '20rem',
            width: '26rem'
        }
    })
);

export const ArSectorSummary: React.FunctionComponent<ArSectorSummaryProps> = observer(({data, totalSectorCount}) => {
    const classes = useStyles();

    const lensPositionData = React.useMemo(()=> {
        return {
            completed : data.lensData.filter(lens => lens.jobInfo !== null).map(lens => lens.position),
            focused: [],
            skipped: data.lensData.filter(lens => lens.skipped).map(lens => lens.position),
        }
    }, [data])

    const containerTemplateModel = BatchContainerStore.get(data.containerId) as BatchContainerModel;

    return (
        <Box>
            <Grid container justifyContent={'center'} className={classes.sectionWrapper}>
                <Box>
                    <ArSectorSummaryInfoCard data={data} totalSectorCount={totalSectorCount}/>
                    <Box className={classes.sectorWrap} mt={1}>
                        {containerTemplateModel && <BatchContainerViewCanvas model={containerTemplateModel} positionData={lensPositionData}/>}
                    </Box>
                </Box>
                <Box mr={16}/>
                <Box mt={2}>
                    <ArSectorSummaryLensTable data={data.lensData}/>
                </Box>
            </Grid>
        </Box>
    );;
});