import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, createStyles, Divider, Grid, makeStyles, Theme, Typography} from "@material-ui/core";
import {grey} from "@material-ui/core/colors";
import {SerializedSectorDatum} from "../../../objects/ar_coating/SectorDatum";
import {t} from "@lingui/macro";
import {ArSectorDomePositionCanvas} from "../ArDomeSectorPositionCanvas";

interface ArSectorSummaryInfoCardProps {
    data: SerializedSectorDatum;
    totalSectorCount: number;
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        fitToContent: {
            width: 'fit-content',
            height: 'fit-content',
            flexWrap: 'nowrap'
        },
        label: {
            fontWeight: 'bold',
            color: grey[600],
            marginRight: theme.spacing(4)
        },
        sectorPositionWrap: {
            height: '6rem'
        }
    })
);

export const ArSectorSummaryInfoCard: React.FunctionComponent<ArSectorSummaryInfoCardProps> = observer(({data, totalSectorCount}) => {
    const classes = useStyles();

    const sectorInfos = React.useMemo(()=> {
        return [
            {label: t`Sector ID`, value: data.sectorId},
            {label: t`Lens Count`, value: data.lensData.filter(data => data.jobInfo !== null).length},
            {label: t`Empty Holes`, value: data.lensData.filter(data => data.skipped).length}
        ]
    }, [data])

    return (
        <Grid container direction={'column'} className={classes.fitToContent}>
            <Grid container alignItems={'center'} className={classes.fitToContent}>
                <Box>
                    <Typography variant={'h4'}>Sector {data.order}</Typography>
                    {
                        sectorInfos.map((data, index) => {
                            return (
                                <div>
                                    {index !== 0 && <Divider/>}
                                    <Grid container justifyContent={'space-between'}>
                                        <Typography variant={'subtitle1'} className={classes.label}> {data.label}</Typography>
                                        <Typography variant={'subtitle1'}>{data.value}</Typography>
                                    </Grid>
                                </div>
                            )
                        })
                    }
                </Box>
                <Box ml={4} className={classes.sectorPositionWrap}>
                    <ArSectorDomePositionCanvas numberOfSectors={totalSectorCount} highlightedSector={data.order-1}/>
                </Box>
            </Grid>
        </Grid>
    );
});