import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, makeStyles, Typography} from "@material-ui/core";
import {grey} from "@material-ui/core/colors";
import {t} from "@lingui/macro";
import {LensDatum, SerializedLensDatum} from "../../../objects/ar_coating/LensDatum";
import classNames from "classnames";
import ReactTable from "react-table";

interface ArSectorSummaryLensTableProps {
    data: SerializedLensDatum[];
}

const useStyles = makeStyles({
    cellWrapper: {
        width: '100%',
        height: '100%',
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center',
    },
    skipped: {
        backgroundColor: grey[300]
    }
});

export const ArSectorSummaryLensTable: React.FunctionComponent<ArSectorSummaryLensTableProps> = observer(({data}) => {
    const classes = useStyles();

    const resolvedCellClasses = (data: LensDatum) => {
        const resolvedClasses = [classes.cellWrapper];

        if(data.skipped){
            resolvedClasses.push(classes.skipped)
        }

        return classNames(resolvedClasses);
    }

    const columns = React.useMemo(() => {
        return [
            {
                Header: t`Lens Position`,
                id: 'lens_position',
                accessor: (data: LensDatum) => data,
                Cell: (cellInfo: { value: LensDatum }) => {
                    return (
                        <div className={resolvedCellClasses(cellInfo.value)}>
                            <Typography variant={'body1'}>{cellInfo.value.position}</Typography>
                        </div>
                    )
                }
            },
            {
                Header: t`Job Number`,
                id: '_jobNumber',
                accessor: (data: LensDatum) => data,
                Cell: (cellInfo: { value: LensDatum }) => {
                    const lensData = cellInfo.value;
                    let text = '';

                    if (lensData.skipped) {
                        text = 'skipped';
                    }

                    if (lensData.jobInfo) {
                        text = lensData.jobInfo.jobNumber;
                    }

                    return (
                        <div className={resolvedCellClasses(cellInfo.value)}>
                            <Typography variant={'body1'}>{text}</Typography>
                        </div>
                    )
                }
            },
            {
                Header: t`Side`,
                id: '_side',
                accessor: (data: LensDatum) => data,
                Cell: (cellInfo: { value: LensDatum }) => {
                    const lensData = cellInfo.value;
                    let text = '';

                    if (lensData.skipped) {
                        text = 'skipped';
                    }

                    if (lensData.jobInfo) {
                        text = lensData.jobInfo.side;
                    }

                    return (
                        <div className={resolvedCellClasses(cellInfo.value)}>
                            <Typography variant={'body1'}>{text}</Typography>
                        </div>
                    )
                }
            }
        ];
    }, [data])

    return (
        <React.Fragment>
            <ReactTable
                data={data}
                columns={columns}
                minRows={20}
                defaultPageSize={20}
                showPageSizeOptions={false}
                defaultSorted={[{ id: 'position', desc: false}]}
                sortable={false}
                getTdProps={() => {
                    return {
                        style: {
                            padding: 0
                        }
                    }
                }}
            />
        </React.Fragment>
    )
});