import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, createStyles, Divider, Grid, makeStyles, Theme, Typography} from "@material-ui/core";
import {PaddedPaper} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {SerializedArBatchData} from "../../../objects/batch_workstation_manager/ArBatchManager";
import {BatchData} from "../../../stores/BatchWorkstationStore";
import {grey} from "@material-ui/core/colors";
import {BatchToolBarBatchInfoList} from "../../batch_workstations/toolbar/BatchToolbarBactchInfoList";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {BatchSummaryActions} from "../../batch_workstations/toolbar/BatchSummaryActions";
import {SerializedSectorDatum} from "../../../objects/ar_coating/SectorDatum";

interface ArBatchSummaryProps {
    data: BatchData;
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        label: {
            fontWeight: 'bold',
            color: grey[600]
        }
    })
);

export const ArBatchSummaryHeader: React.FunctionComponent<ArBatchSummaryProps> = observer(({data}) => {
    const classes = useStyles();

    const systemSettings = SystemSettingStore.selectedModel as SystemSettingModel;

    const batchData = data.batchData as SerializedArBatchData;

    const countCompletedLens = React.useCallback((sectors: SerializedSectorDatum[]) => {
        return sectors.map(sector => sector.lensData.reduce((acc, val) => {
            return acc += (val.jobInfo !== null ? 1 : 0);
        }, 0)).reduce((acc, val) => {
            return acc += val;
        });
    }, []);

    const countEmptyHoles = React.useCallback((sectors: SerializedSectorDatum[]) => {
        return sectors.map(sector => sector.lensData.reduce((acc, val) => {
            return acc += ((val.jobInfo === null || val.skipped) ? 1 : 0);
        }, 0)).reduce((acc, val) => {
            return acc += val;
        });
    }, []);

    const batchInfos = React.useMemo(()=> {
        const displayInfo = [
            {label: t`Created At`, value: systemSettings ? systemSettings.printDateTime(data.startedAtTime) : ''},
            {label: t`Sectors`, value: batchData.sectorData.length.toString()},
            {label: t`Lens Count`, value: countCompletedLens(batchData.sectorData)},
            {label: t`Skipped Holes`, value: countEmptyHoles(batchData.sectorData)}
        ];

        const concaveData = batchData.runs.find(run => run.domeSide == 'CC')
        const convexData = batchData.runs.find(run => run.domeSide == 'CX')

        displayInfo.push({label: t`Dome Lens Side`, value:  (concaveData && convexData) ? 'CC and CX' : (convexData ? 'Only CX' : 'Only CC')})

        if(convexData){
            displayInfo.push({label: t`Recipe (CX)`, value: convexData.recipeName});
        }

        if(concaveData){
            displayInfo.push({label: t`Recipe (CC)`, value: concaveData.recipeName});
        }

        return displayInfo;
    }, [data, systemSettings])

    return (
        <PaddedPaper>
            <Typography variant={'h4'}>Batch ID {data.batchId}</Typography>
            <Box mb={1}>
                <Grid container>
                    <BatchToolBarBatchInfoList data={batchInfos}/>
                </Grid>
            </Box>
            <Divider/>
            <BatchSummaryActions/>
        </PaddedPaper>
    );;
});