import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, createStyles, Divider, Grid, makeStyles, Theme, Typography} from "@material-ui/core";
import {PaddedPaper} from "@rx-suite/ui";
import {BatchData} from "../../../../stores/BatchWorkstationStore";
import {ArBatchSummaryHeader} from "../../summary/ArSummaryHeader";
import {ArBatchData, ArBatchManager} from "../../../../objects/batch_workstation_manager/ArBatchManager";
import {ArSectorSummary} from "../../summary/ArSectorSummary";
import Barcode from "react-barcode";
import {useBatchManagerContext} from "../../../hooks/useBatchManagerContext";

interface ArBatchSummaryProps {
    data: BatchData;
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        barcodeSectionWrapper: {
            padding: theme.spacing(4)
        },
        barcodeWrapper: {
            width: 'fit-content'
        }
    })
);

export const ArBatchSummary: React.FunctionComponent<ArBatchSummaryProps> = observer(({data}) => {
    const classes = useStyles();

    const batchData = data.batchData as ArBatchData;

    const manager = useBatchManagerContext() as ArBatchManager;

    return (
        <React.Fragment>
            <Box mb={1}>
                <ArBatchSummaryHeader data={data}/>
            </Box>
            {
                !manager && // only display the batch run code when coming from the index page
                <Box mb={1}>
                    <PaddedPaper className={classes.barcodeSectionWrapper}>
                        <Grid container justifyContent={'space-evenly'}>
                            {
                                batchData.runs.map((run) => {
                                    return (
                                        <Grid container direction={'column'} alignItems={'center'} className={classes.barcodeWrapper}>
                                            <Box>
                                                <Typography variant={'h5'}>{`Run Code for ${run.domeSide} Side`}</Typography>
                                            </Box>
                                            <Barcode value={run.run_key}/>
                                        </Grid>
                                    )
                                })
                            }
                        </Grid>
                    </PaddedPaper>
                </Box>
            }
            <PaddedPaper>
                {
                    batchData.sectorData.map((sector, index) => {
                        return (
                            <div>
                                {index !== 0 && <Divider/>}
                                <ArSectorSummary data={sector} totalSectorCount={batchData.sectorData.length}/>
                            </div>
                        )
                    })
                }
            </PaddedPaper>
        </React.Fragment>
    );
});