import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {ArBatchManager} from "../../../../objects/batch_workstation_manager/ArBatchManager";
import {Box, Grid, Theme, Typography} from "@material-ui/core";
import {useBatchManagerContext} from "../../../hooks/useBatchManagerContext";
import {AddJobToBatchInputField} from "../../../batch_workstations/AddJobToBatchInputField";
import {t, Trans} from "@lingui/macro";
import {ButtonField} from "@rx-suite/ui";
import {ArrowForward, Check} from "@material-ui/icons";
import {green} from "@material-ui/core/colors";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faClipboardListCheck} from "@rx-suite/pro-solid-svg-icons";
import {useEffect} from "react";

const useStyles = makeStyles((theme: Theme) => ({
        scanFieldWrapper: {
            margin: 'auto'
        },
        messageWrapper: {
            width: 'fit-content'
        },
        sectorFullText: {
            color: green[600],
        },
        icon: {
            fontSize: '1.25rem',
            color: green[600],
            marginRight: theme.spacing(0.5)
        },
    })
);

export const ArAddToSectorField: React.FunctionComponent = observer(({}) => {
    const classes = useStyles();

    const manager = useBatchManagerContext() as ArBatchManager;
    const scanInputRef = React.useRef<HTMLInputElement>();

    const [isLoadingSummary, setIsLoadingSummary] = React.useState<boolean>(false);

    const handleGoToSummary = React.useCallback(async () => {
        setIsLoadingSummary(true);
        try {
            await manager.saveCurrentBatchData();
        }catch (e) {
            console.error(e);
            // If the save fails, still go to summary
        }
        setIsLoadingSummary(false);
        manager.setShowBatchSummary(true);
    }, []);

    useEffect(() => {
        if(scanInputRef.current){
            scanInputRef.current.focus();
        }
    }, [scanInputRef, manager.currentSector])

    if(!manager.currentSector.isComplete){
        return (
            <Box mb={2} mt={2} className={classes.scanFieldWrapper}>
                <AddJobToBatchInputField disabled={false} inputRef={scanInputRef as React.MutableRefObject<HTMLInputElement>}/>
            </Box>
        )
    }

    if(manager.domeIsComplete){
        return (
            <Grid container alignItems={'center'} justifyContent={'space-between'}>
                <Grid container alignItems={'center'} className={classes.messageWrapper}>
                    <Check className={classes.icon}/>
                    <Typography variant={'h6'} className={classes.sectorFullText}>
                        <Trans>
                            All Sectors Completed
                        </Trans>
                    </Typography>
                </Grid>
                <ButtonField
                    startIcon={<FontAwesomeIcon icon={faClipboardListCheck}/>}
                    text={t`Finalize Batch`}
                    onClick={handleGoToSummary}
                    loading={isLoadingSummary}
                    size='large'
                    color='secondary'
                    variant='contained'
                />
            </Grid>
        )
    }

    return (
        <Grid container alignItems={'center'} justifyContent={'space-between'}>
            <Grid container alignItems={'center'} className={classes.messageWrapper}>
                <Check className={classes.icon}/>
                <Typography variant={'h6'} className={classes.sectorFullText}>
                    <Trans>
                        Sector Complete
                    </Trans>
                </Typography>
            </Grid>
            {
                !manager.currentSectorIsLastSector &&
                <ButtonField
                    text={t`Next Sector`}
                    endIcon={<ArrowForward/>}
                    onClick={() => manager.jumpToNextSector()}
                    size='large'
                    color='secondary'
                    variant='contained'
                />
            }
        </Grid>
    )
});