import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {ArBatchManager} from "../../../../objects/batch_workstation_manager/ArBatchManager";
import {ArSectorEditLensTable} from "./ArSectorEditLensTable";
import {Box, Grid, Theme, useMediaQuery} from "@material-ui/core";
import {useBatchManagerContext} from "../../../hooks/useBatchManagerContext";
import {BatchContainerViewCanvas} from "../../../batch_container/BatchContainerViewCanvas";
import {BatchContainerStore} from "../../../../stores/BatchContainerStore";
import {LoaderWithText} from "../../../generic/LoaderWithText";
import {t} from "@lingui/macro";
import {ArAddToSectorField} from "./ArAddToSectorField";

const useStyles = makeStyles((theme: Theme) => ({
        domeRenderSectionWrap: {
            width: 'fit-content'
        },
        domeRenderWrapLarge: {
            width: '40rem',
            height: '30rem',
            margin: theme.spacing(1)
        },
        domeRenderWrapSmall: {
            width: '30rem',
            height: '23rem',
            margin: theme.spacing(1)
        }
    })
);

export const ArSectorEditor: React.FunctionComponent = observer(({}) => {
    const classes = useStyles();

    const manager = useBatchManagerContext() as ArBatchManager;

    const template = BatchContainerStore.get(manager.currentSector.containerId);

    const isLargeDisplay = useMediaQuery('(min-width:1400px)');

    if(!template){
        return (
            <LoaderWithText message={t`Loading AR sector information...`}/>
        )
    }

    return (
        <React.Fragment>
            <Grid container justifyContent={'space-evenly'}>
                <Grid item>
                    <Box mb={2} mt={2}>
                        <ArAddToSectorField/>
                    </Box>
                    <ArSectorEditLensTable/>
                </Grid>
                <Grid container alignItems={'center'} className={classes.domeRenderSectionWrap}>
                    <div className={isLargeDisplay ? classes.domeRenderWrapLarge : classes.domeRenderWrapSmall}>
                        <BatchContainerViewCanvas model={template} positionData={manager.currentSector.lensDataPositionsStates}/>
                    </div>
                </Grid>
            </Grid>
        </React.Fragment>
    );
});