import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {ArBatchManager} from "../../../../objects/batch_workstation_manager/ArBatchManager";
import {ButtonField, PaddedPaper, WorkstationTabWrapper} from "@rx-suite/ui";
import {Box, Button, Grid, Tab, Theme, Typography, useMediaQuery} from "@material-ui/core";
import {CheckCircleOutline, ErrorOutline} from "@material-ui/icons";
import {green, grey} from "@material-ui/core/colors";
import {t} from "@lingui/macro";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faClipboardListCheck} from "@rx-suite/pro-solid-svg-icons";
import {useBatchManagerContext} from "../../../hooks/useBatchManagerContext";
import {SectorDatum} from "../../../../objects/ar_coating/SectorDatum";
import classNames from "classnames";

const useStyles = makeStyles((theme: Theme) => ({
        wrapperVertical: {
            marginRight: theme.spacing(1)
        },
        wrapperHorizontal: {
            width: '100%',
            marginBottom: theme.spacing(1)
        },
        buttonGroupWrapper: {
            height: '100%'
        },
        buttonWrapper: {
            flexGrow: 1,
            width: 'fit-content'
        },
        button: {
            padding: '0px 16px',
            height: '100%',
            width: '100%'
        },
        selected: {
            backgroundColor: grey[200]
        },
        icon: {
            fontSize: '1.75rem'
        },
        completed: {
            color: green[600]
        }
    })
);

export const ArSectorNavigation: React.FunctionComponent = observer(({}) => {
    const classes = useStyles();
    const manager = useBatchManagerContext() as ArBatchManager;

    const isLargeDisplay =  useMediaQuery('(min-width:1400px)');

    const tabs = (() => {
        return manager.sectorData.map((sector: SectorDatum) => ({
                label: `Sector ${sector.order}`,
                icon: sector.isComplete ? <CheckCircleOutline className={classNames(classes.icon, classes.completed)}/> : <ErrorOutline className={classes.icon}/>
            })
        )
    })();

    return (
        <PaddedPaper className={isLargeDisplay ? classes.wrapperVertical : classes.wrapperHorizontal}>
            <Grid container direction={isLargeDisplay ? 'column' : 'row'} justifyContent={'space-evenly'} className={classes.buttonGroupWrapper}>
                {
                    tabs.map((tab, i) => {
                        return (
                            <Grid container alignItems={'center'} className={classNames(classes.buttonWrapper)}>
                                <Button
                                    key={`tab-${tab.label}-${i}`}
                                    onClick={() => manager.setSectorNumber(i)}
                                    className={manager.currentSectorIndex !== i ? classes.button : classNames(classes.button, classes.selected)}
                                    disabled={manager.controlsDisabled}
                                >
                                    <Grid direction={'column'}>
                                        <Box>
                                            {tab.icon}
                                        </Box>
                                        <Typography variant={'subtitle1'}>{tab.label}</Typography>
                                    </Grid>
                                </Button>
                            </Grid>
                        )
                    })
                }
            </Grid>
        </PaddedPaper>
    );
});