import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, Grid, IconButton, makeStyles, Theme, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {ArBatchManager} from "../../../../../objects/batch_workstation_manager/ArBatchManager";
import {ArSectorEditToolbarActions} from "./ArSectorEditToolbarActions";
import {useBatchManagerContext} from "../../../../hooks/useBatchManagerContext";
import {ArSectorDomePositionCanvas} from "../../../ArDomeSectorPositionCanvas";
import {BatchToolBarBatchInfoList} from "../../../../batch_workstations/toolbar/BatchToolbarBactchInfoList";
import {Edit} from "@material-ui/icons";
import {useModalHandler} from "../../../../hooks/useModalHandler";
import {EditSectorIdDialog} from "./EditSectorIdDialog";
import {Conditional} from "@rx-suite/ui";

const useStyles = makeStyles((theme: Theme) => ({
        sectorInformationSection: {
            flexGrow: 1
        },
        noMargin: {
            margin: '0'
        }
    })
);

export const ArSectorEditToolbar: React.FunctionComponent = observer(({}) => {
    const classes = useStyles();
    const manager = useBatchManagerContext() as ArBatchManager;

    const sectorData = manager.currentSector;

    const [changeSectorIdDialogOpen, handleCloseChangeSectorId, handleOpenChangeSectorId] = useModalHandler();

    if(!sectorData){
        return null;
    }

    const sectorInfos = () => {
        return [
            {label: t`Sector ID`, value:  sectorData.sectorId},
            {label: t`Lens Count`, value:  sectorData.completedHolesCount.toString()},
            {label: t`Skipped Holes`, value:  sectorData.emptyHolesCount.toString()}
        ]
    }

    return (
        <Box mb={1}>
            <Grid container justifyContent={'space-between'} alignItems={'center'}>
                <Box>
                    <Grid container item className={classes.sectorInformationSection}>
                        <div>
                            <ArSectorDomePositionCanvas numberOfSectors={manager.sectorCount} highlightedSector={manager.currentSector.order - 1}/>
                        </div>
                        <Box ml={2}>
                            <Box>
                                <Grid container>
                                    <Typography variant={'h5'} >{t`Sector ${manager.currentSector.order}`}</Typography>
                                    <Box ml={0.5}>
                                        <IconButton size={'small'} onClick={handleOpenChangeSectorId}>
                                            <Edit/>
                                        </IconButton>
                                    </Box>
                                    <EditSectorIdDialog
                                        open={changeSectorIdDialogOpen}
                                        handleClose={handleCloseChangeSectorId}
                                    />
                                </Grid>
                                <Box mt={0.5}>
                                    <BatchToolBarBatchInfoList data={sectorInfos()}/>
                                </Box>
                            </Box>
                        </Box>
                    </Grid>
                </Box>
                <Grid item>
                    <ArSectorEditToolbarActions/>
                </Grid>
            </Grid>
        </Box>
    )
});

