import * as React from "react";
import {observer} from "mobx-react-lite";
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faRecycle, faStepForward} from "@rx-suite/pro-solid-svg-icons";
import {useModalHandler} from "../../../../hooks/useModalHandler";
import {InformationDialog} from "../../../../batch_workstations/dialogs/InformationalDialog";
import {WarningDialog} from "../../../../batch_workstations/dialogs/WarningDialog";
import {useBatchManagerContext} from "../../../../hooks/useBatchManagerContext";
import {ArBatchManager} from "../../../../../objects/batch_workstation_manager/ArBatchManager";
import {useEffect} from "react";

export const ArSectorEditToolbarActions: React.FunctionComponent = observer(({}) => {
    const manager = useBatchManagerContext() as ArBatchManager;

    const [resetSectorDialogOpen, handleCloseResetSector, handleOpenResetSector] = useModalHandler();
    const [skipSectorOpen, handleCloseSkipSector, handleOpenSkipSector] = useModalHandler();

    const handleReset = React.useCallback(async () => {
        handleCloseResetSector();
        await manager.restartCurrentSector();
    }, []);

    const handleSkipSector = React.useCallback(async () => {
        handleCloseSkipSector();
        manager.skipAllHolesInCurrentSector();
        manager.jumpToNextSector();
    }, []);

    return (
        <React.Fragment>
            <ButtonField
                startIcon={<FontAwesomeIcon icon={faStepForward}/>}
                disabled={manager.controlsDisabled || manager.currentSector.isComplete}
                text={t`Skip Sector`}
                variant={'contained'}
                color={'primary'}
                onClick={handleOpenSkipSector}
            />
            <ButtonField
                startIcon={<FontAwesomeIcon icon={faRecycle}/>}
                disabled={manager.controlsDisabled}
                text={t`Reset Sector`}
                variant={'contained'}
                color={'primary'}
                onClick={handleOpenResetSector}
            />
            <InformationDialog
                message={t`This action will set skip any remaining empty holes and proceed with the next sector.`}
                open={skipSectorOpen}
                onConfirm={handleSkipSector}
                handleClose={handleCloseSkipSector}
            />
            <WarningDialog
                warningMessage={t`This action will clear this sector template and remove all assigned jobs.`}
                open={resetSectorDialogOpen}
                onConfirm={handleReset}
                handleClose={handleCloseResetSector}
            />
        </React.Fragment>
    )
});

