import * as React from "react";
import {observer} from "mobx-react-lite";
import {
    Box,
    Button,
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    Grid,
    makeStyles,
    Theme, Typography
} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {ButtonField, Conditional, InputField} from "@rx-suite/ui";
import {green} from "@material-ui/core/colors";
import {useBatchManagerContext} from "../../../../hooks/useBatchManagerContext";
import {useEffect} from "react";
import {ArBatchManager} from "../../../../../objects/batch_workstation_manager/ArBatchManager";

type EditSectorIdDialogProps = {
    open: boolean,
    handleClose: () => void
}

const useStyles = makeStyles((theme: Theme) => ({
        useDefaultButton: {
            backgroundColor: green[600]
        },
        inputField: {
            flexGrow: 1
        }
    })
);

export const EditSectorIdDialog: React.FunctionComponent<EditSectorIdDialogProps> = observer(({open, handleClose}) => {
    const classes = useStyles();

    const manager = useBatchManagerContext() as ArBatchManager;

    const [tempSectorId, setTempSectorId] = React.useState<string>(manager.currentSector.sectorId);

    useEffect(() => {
        setTempSectorId(manager.currentSector.sectorId);
    }, [open]) // use open so that everytime the dialog is open, force refresh

    const handleUpdateSectorId = () => {
        manager.currentSector.setSectorId(tempSectorId);
        handleClose();
    }

    const useDefaultSectorId = () => {
        setTempSectorId(manager.currentSector.defaultSectorId);
    }

    const showSectorUniqueError = (tempSectorId !== manager.currentSector.sectorId) && !manager.sectorIdIsUnique(tempSectorId)

    return (
        <React.Fragment>
            <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title" fullWidth={true} maxWidth={'xs'}>
                <DialogTitle>
                    <Trans>Edit Sector ID</Trans>
                </DialogTitle>
                <DialogContent>
                    <Box mb={4}>
                        <Grid container alignItems={'center'}>
                            <InputField
                                label={t`Sector ID`}
                                onChange={(e) => setTempSectorId(e.target.value)}
                                value={tempSectorId}
                                className={classes.inputField}
                            />

                            <ButtonField
                                text={t`Use Default`}
                                variant={'contained'}
                                className={classes.useDefaultButton}
                                onClick={useDefaultSectorId}
                            />
                        </Grid>
                        <Conditional condition={showSectorUniqueError}>
                            <Typography variant={'caption'} color={'error'}>{t`One or more sector is already using this ID.`}</Typography>
                        </Conditional>
                    </Box>
                </DialogContent>
                <DialogActions>
                    <Button onClick={handleClose} color="secondary" variant={'outlined'}>
                        <Trans>Cancel</Trans>
                    </Button>
                    <Button onClick={handleUpdateSectorId} color="secondary" variant={'contained'} disabled={tempSectorId.trim() === '' || showSectorUniqueError}>
                        <Trans>Update</Trans>
                    </Button>
                </DialogActions>
            </Dialog>
        </React.Fragment>
    )
});

