import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {BatchContainerEditRenderer} from "../../objects/canvas_renderer/batch_container/BatchContainerEditRenderer";
import {useEffect} from "react";
import {CanvasLayout} from "../../objects/canvas_renderer/CanvasRenderer";
import {BatchContainerModel} from "../../stores/BatchContainerStore";
import {BatchContainerViewRenderer} from "../../objects/canvas_renderer/batch_container/BatchContainerViewRender";

export type BatchContainerEditCanvasProps = {
    container: BatchContainerModel;
    renderer: BatchContainerEditRenderer;
};

const useStyles = makeStyles({
    canvas: {
        height: '100%',
        width: '100%',
        touchAction: 'none',
        outline: 'none',
        border: '1px solid black'
    }
});

export const BatchContainerEditCanvas: React.FunctionComponent<BatchContainerEditCanvasProps> = observer(({container, renderer}) => {

    const classes = useStyles();

    const setCanvasRef = React.useCallback((e) => {
        renderer.setCanvasRef(e)
    }, [renderer]);
    const handleMouseDown = React.useCallback((e) => {
        renderer.handleMouseDown(e)
    }, [renderer]);
    const handleMouseMove = React.useCallback((e) => {
        renderer.handleMouseMove(e)
    }, [renderer]);
    const handleMouseUp = React.useCallback((e) => {
        renderer.handleMouseUp(e)
    }, [renderer]);
    const handleMouseLeave = React.useCallback((e) => {
        renderer.handleMouseLeave(e)
    }, [renderer]);
    const handleKeyDown = React.useCallback((e) => {
        renderer.handleKeyDown(e)
    }, [renderer]);

    useEffect(() => {
        renderer.setLayout((container.viewModel as unknown) as CanvasLayout);
        renderer.draw();
    })

    useEffect(() => {
        renderer.draw();
    }, [container.viewModel.components])

    return (
        <React.Fragment>
            <canvas
                tabIndex={0} //required for onKeyDown to fire
                width={BatchContainerViewRenderer.BATCH_CONTAINER_CANVAS_WIDTH}
                height={BatchContainerViewRenderer.BATCH_CONTAINER_CANVAS_HEIGHT}
                className={classes.canvas}
                onMouseDown={handleMouseDown}
                onMouseMove={handleMouseMove}
                ref={setCanvasRef}
                onTouchMove={handleMouseMove}
                onTouchStart={handleMouseDown}
                onTouchEnd={handleMouseUp}
                onMouseUp={handleMouseUp}
                onKeyDown={handleKeyDown}
                onMouseLeave={handleMouseLeave}
            />
        </React.Fragment>
    )
});