import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {BatchContainerPositionStates, BatchContainerViewRenderer} from "../../objects/canvas_renderer/batch_container/BatchContainerViewRender";
import {CanvasLayout} from "../../objects/canvas_renderer/CanvasRenderer";
import {BatchContainerModel} from "../../stores/BatchContainerStore";
import {useEffect} from "react";

export type BatchContainerViewCanvasProps = {
    model: BatchContainerModel;
    positionData?: BatchContainerPositionStates;
};

const useStyles = makeStyles({
    canvas: {
        border: 'solid 1px lightgray',
        width: '100%',
        height: '100%',
        touchAction: 'none',
        outline: 'none'
    }
});

export const BatchContainerViewCanvas: React.FunctionComponent<BatchContainerViewCanvasProps> = observer(({model, positionData}) => {
    const classes = useStyles();
    const renderer = new BatchContainerViewRenderer();

    const setCanvasRef = React.useCallback((e) => {
        if (!renderer) return;
        renderer.setCanvasRef(e);
        renderer.setLayout((model as unknown) as CanvasLayout);
    }, [renderer]);

    useEffect(() => {
        if (!renderer || !positionData) return;
        renderer.setPositionStates(positionData);
    }, [renderer, positionData])

    return (
        <React.Fragment>
            <canvas
                width={BatchContainerViewRenderer.BATCH_CONTAINER_CANVAS_WIDTH}
                height={BatchContainerViewRenderer.BATCH_CONTAINER_CANVAS_HEIGHT}
                className={classes.canvas}
                ref={setCanvasRef}
            />
        </React.Fragment>
    )
});