import {Button, Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import * as React from "react";
import {observer} from "mobx-react-lite";
import {ModelProvider} from "@rx-suite/ui";
import {useSnackbar} from "notistack";
import {FileUpload} from "../../generic/FileUpload";
import {BatchContainerComponentModel} from "../../../stores/BatchContainerComponentStore";
import {BatchContainerEditRenderer} from "../../../objects/canvas_renderer/batch_container/BatchContainerEditRenderer";

export type AddLayoutImageModalProps = {
    model: BatchContainerComponentModel;
    open: boolean;
    handleClose: () => void;
    renderer: BatchContainerEditRenderer;
};

export const AddBatchContainerImageModal: React.FunctionComponent<AddLayoutImageModalProps> = observer(({
                                                                                                    model,
                                                                                                    open,
                                                                                                    handleClose,
                                                                                                    renderer
                                                                                                }) => {
    const {enqueueSnackbar} = useSnackbar();

    const [fileName, setFileName] = React.useState("");

    const handleSubmit = React.useCallback(() => {
        enqueueSnackbar(`${t`Image Added`}`, {variant: "success"});
        renderer.layout.viewModel.components.push(model);
        renderer.setSelectedComponent(model);
        handleClose();
    }, [model, enqueueSnackbar, renderer, handleClose]);

    const handleSelectImage = React.useCallback((e: any) => {
        const file = e.target.files[0];
        model.viewModel.file = file;
        setFileName(file.name);
    }, [model]);

    return <Dialog open={open} onClose={handleClose} maxWidth={'lg'} fullWidth>
        <ModelProvider value={model}>
            <DialogTitle>{t`Add Image`}</DialogTitle>
            <DialogContent>
                <FileUpload onChange={handleSelectImage} fileName={fileName}/>
                <DialogActions>
                    <Button onClick={handleClose} color={"secondary"}><Trans>Close</Trans></Button>
                    <Button onClick={handleSubmit} color={"secondary"}
                            disabled={!model.viewModel.file || !model.viewModel.name}><Trans>Submit</Trans></Button>
                </DialogActions>
            </DialogContent>
        </ModelProvider>
    </Dialog>
});