import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {ButtonField} from "@rx-suite/ui";
import {AddCircle, Image} from "@material-ui/icons";
import {t} from "@lingui/macro";
import {BatchContainerEditRenderer} from "../../../objects/canvas_renderer/batch_container/BatchContainerEditRenderer";
import {BatchContainerComponentStore, ComponentType} from "../../../stores/BatchContainerComponentStore";
import {AddBatchContainerImageModal} from "./AddBatchContainerImageModal";
import {useModalHandler} from "../../hooks/useModalHandler";

type BatchContainerEditControlsProps = {
    renderer: BatchContainerEditRenderer
};

const useStyles = makeStyles(theme => ({

}));

export const BatchContainerEditControls: React.FunctionComponent<BatchContainerEditControlsProps> = observer(({renderer}) => {
    const [addBatchContainerOpen, handleCloseAddBatchContainer, handleOpenAddBatchContainer] = useModalHandler();

    const createBatchComponent = React.useCallback((type: ComponentType) => {
        const component = BatchContainerComponentStore.createModel();
        component.viewModel.component_type = type;
        if(type === 'batch_image'){
            component.viewModel.z_index = 0;
        }else{
            component.viewModel.z_index = 1;
        }

        return component;
    }, []);

    const handleAddLensPosition = React.useCallback(() => {
        const component = createBatchComponent('batch_position');
        component.viewModel.position = renderer.layout.viewModel.component_count + 1;
        renderer.layout.viewModel.components.push(component);
        renderer.setSelectedComponent(component);
    }, [renderer]);

    if(!renderer.ready){
        return null;
    }

    return (
        <>
            <ButtonField
                startIcon={<AddCircle/>}
                text={t`Add Lens Position`}
                onClick={handleAddLensPosition}
            />
            <ButtonField
                startIcon={<Image/>}
                text={t`Add Container Image`}
                onClick={handleOpenAddBatchContainer}
                disabled={renderer.hasContainerImage}
            />
            <AddBatchContainerImageModal
                model={createBatchComponent('batch_image')}
                open={addBatchContainerOpen}
                handleClose={handleCloseAddBatchContainer}
                renderer={renderer}/>
        </>
    )
});