import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, Dialog, DialogContent, Grid, makeStyles, Theme, Typography} from "@material-ui/core";
import {grey} from "@material-ui/core/colors";
import {t} from "@lingui/macro";
import {ButtonField} from "@rx-suite/ui";
import {ErrorOutline} from "@material-ui/icons";

type InformationDialogProps = {
    message: string | null;
    open: boolean,
    onConfirm?: () => Promise<void>;
    handleClose: () => void
}

const useStyles = makeStyles((theme: Theme) => ({
        infoIcon: {
            color: grey[600],
            fontSize: '6.75rem'
        },
        warningText: {
            textAlign: 'center'
        },
        confirmText: {
            textAlign: 'center',
            fontWeight: 'bold'
        }
    })
);

export const InformationDialog: React.FunctionComponent<InformationDialogProps> = observer(({message, open, onConfirm, handleClose}) => {
    const classes = useStyles();

    if(message === null){
        return;
    }

    return (
        <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title" fullWidth={true} maxWidth={'xs'}>
            <DialogContent>
                <Grid container direction={'column'} alignItems={'center'}>
                    <ErrorOutline className={classes.infoIcon}/>
                    <Typography className={classes.warningText} variant={'h6'}>{message}</Typography>
                </Grid>
                <Box mt={2}>
                    <Grid container justifyContent={"center"}>
                        {onConfirm &&
                            <div>
                                <ButtonField
                                    text={t`Confirm`}
                                    variant={'contained'}
                                    onClick={onConfirm}
                                    size={'large'}
                                    color={'secondary'}
                                />
                                <ButtonField
                                    text={t`Cancel`}
                                    variant={'contained'}
                                    onClick={handleClose}
                                    size={'large'}
                                />
                            </div>
                        }
                        {!onConfirm && // If there is no confirm action, just show a single 'OK' button
                            <ButtonField
                                text={t`OK`}
                                variant={'contained'}
                                onClick={handleClose}
                                size={'large'}
                                color={'secondary'}
                            />
                        }
                    </Grid>
                </Box>
            </DialogContent>
        </Dialog>

    )
});

