import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, Dialog, DialogContent, Grid, makeStyles, Theme, Typography} from "@material-ui/core";
import {grey, red} from "@material-ui/core/colors";
import {t, Trans} from "@lingui/macro";
import {WarningRounded} from "@material-ui/icons";
import {ButtonField} from "@rx-suite/ui";

type WarningDialogProps = {
    warningMessage: string;
    open: boolean,
    onConfirm: () => Promise<void>;
    handleClose: () => void
}

const useStyles = makeStyles((theme: Theme) => ({
        warningIcon: {
            color: grey[600],
            fontSize: '6.75rem'
        },
        warningText: {
            textAlign: 'center'
        },
        confirmText: {
            textAlign: 'center',
            fontWeight: 'bold'
        },
        confirmButton: {
            background: red[600]
        }
    })
);

export const WarningDialog: React.FunctionComponent<WarningDialogProps> = observer(({warningMessage, open, onConfirm, handleClose}) => {
    const classes = useStyles();

    return (
        <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title" fullWidth={true} maxWidth={'xs'}>
            <DialogContent>
                <Grid container direction={'column'} alignItems={'center'}>
                    <WarningRounded className={classes.warningIcon}/>
                    <Typography className={classes.warningText} variant={'h6'}>{warningMessage}</Typography>
                </Grid>
                <Box mt={4}>
                    <Typography variant={'caption1'} className={classes.confirmText}>
                        <Trans>This action cannot be undone. Are you sure you wish to proceed?</Trans>
                    </Typography>
                </Box>
                <Box mt={2}>
                    <Grid container justifyContent={"center"}>
                        <ButtonField
                            text={t`Confirm`}
                            variant={'contained'}
                            onClick={onConfirm}
                            size={'large'}
                            className={classes.confirmButton}
                        />
                        <ButtonField
                            text={t`Cancel`}
                            variant={'contained'}
                            onClick={handleClose}
                            size={'large'}
                        />
                    </Grid>
                </Box>
            </DialogContent>
        </Dialog>
    )
});

