import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, Container, Grid, makeStyles, Typography} from "@material-ui/core";
import {useBatchManagerContext} from "../../hooks/useBatchManagerContext";
import {ButtonField, Conditional, IfFalse, IfTrue, PaddedPaper} from "@rx-suite/ui";
import {AccessTime, ArrowBack, Error} from "@material-ui/icons";
import {t, Trans} from "@lingui/macro";
import {grey, red} from "@material-ui/core/colors";
import classNames from "classnames";
import {useSnackbar} from "notistack";

const useStyles = makeStyles((theme) => ({
    paddedPaper: {
        padding: theme.spacing(4)
    },
    icon: {
        fontSize: '7.5rem',
        color: red[900]
    },
    text: {
        textAlign: 'center'
    },
    primary: {
        fontSize: '2.315rem'
    },
    secondary: {
        fontSize: '1.9rem'
    },
    sub: {
        fontSize: '1.5rem',
        color: grey[500]
    },
    errorInfoBox: {
        padding: theme.spacing(1),
        width: '100%',
        border: `solid 1px ${grey[300]}`,
        height: '200px',
        overflowY: 'scroll'
    }
}));

export const BatchWorkstationErrorForm: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const manager = useBatchManagerContext();
    const {enqueueSnackbar} = useSnackbar();

    const [isReturningToEdit, setIsReturningToEdit] = React.useState<boolean>(false);

    const handleBackToBatchEdit = React.useCallback(async () => {
        setIsReturningToEdit(true);
        try {
            await manager.returnToEditScreen();
        }catch (e) {
            console.error(e);
            enqueueSnackbar(`${t`Error while returning to batch edit!`}`, {variant: "error"})

            //only release the loader on error, otherwise the form transition will handle releasing the loaded
            setIsReturningToEdit(false)
        }
    }, [])

    return (
        <Container maxWidth={'sm'}>
            <PaddedPaper elevation={2} className={classes.paddedPaper}>
                <Grid container direction={'column'} alignItems={'center'}>
                    <Typography className={classNames(classes.text, classes.primary)}>
                        <Trans>An error occurred while saving</Trans>
                    </Typography>
                    <Typography className={classNames(classes.text, classes.primary)}>
                        {t`Batch ID: ${manager.data.batchId}`}
                    </Typography>
                    <Box mt={2} mb={2}>
                        <Error className={classes.icon}/>
                    </Box>
                    <Box>
                        <Typography className={classNames(classes.text, classes.sub)}>
                            <Trans>Error Details</Trans>
                        </Typography>
                    </Box>
                    <div className={classes.errorInfoBox}>
                        <Conditional condition={manager.batchSubmitError !== null}>
                            <IfTrue>
                                {manager.batchSubmitError}
                            </IfTrue>
                            <IfFalse>
                                <Trans>Unknown Error - Please contact support.</Trans>
                            </IfFalse>
                        </Conditional>
                    </div>
                    <Box mt={2}>
                        <ButtonField
                            startIcon={<ArrowBack/>}
                            text={t`Back to Batch Edit`}
                            size={'large'}
                            onClick={handleBackToBatchEdit}
                            loading={isReturningToEdit}
                        />
                    </Box>
                </Grid>
            </PaddedPaper>
        </Container>
    );
});