import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, Container, Grid, makeStyles, Typography} from "@material-ui/core";
import {useBatchManagerContext} from "../../hooks/useBatchManagerContext";
import {PaddedPaper} from "@rx-suite/ui";
import {AccessTime} from "@material-ui/icons";
import {t, Trans} from "@lingui/macro";
import {grey} from "@material-ui/core/colors";
import classNames from "classnames";

const useStyles = makeStyles((theme) => ({
    paddedPaper: {
        padding: theme.spacing(4)
    },
    icon: {
        fontSize: '7.5rem',
        color: grey[600]
    },
    text: {
        textAlign: 'center'
    },
    primary: {
        fontSize: '2.315rem'
    },
    secondary: {
        fontSize: '1.9rem'
    },
    sub: {
        fontSize: '1.5rem',
        color: grey[500]
    }
}));

export const BatchWorkstationSavingForm: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const manager = useBatchManagerContext();

    return (
        <Container maxWidth={'sm'}>
            <PaddedPaper elevation={2} className={classes.paddedPaper}>
                <Grid container direction={'column'} alignItems={'center'}>
                    <Typography className={classNames(classes.text, classes.primary)}>
                        {t`Batch ID: ${manager.data.batchId}`}
                    </Typography>
                    <Typography className={classNames(classes.text, classes.primary)}>
                        <Trans>is currently being saved.</Trans>
                    </Typography>
                    <Box mt={2} mb={2}>
                        <AccessTime className={classes.icon}/>
                    </Box>
                    <Box>
                        <Typography className={classNames(classes.text, classes.secondary)}>
                            <Trans>This operation may take several minutes.</Trans>
                        </Typography>
                    </Box>
                    <Box mt={2}>
                        <Typography className={classNames(classes.text, classes.sub)}>
                            <Trans>
                                You may safely leave this page.
                            </Trans>
                        </Typography>
                    </Box>
                </Grid>
            </PaddedPaper>
        </Container>
    );
});