import * as React from "react";
import {observer} from "mobx-react-lite";
import {Box, Divider, Grid, IconButton, makeStyles, Theme, Typography} from "@material-ui/core";
import {PaddedPaper} from "@rx-suite/ui";
import {green, grey, red} from "@material-ui/core/colors";
import {BatchManager} from "../../../objects/batch_workstation_manager/BatchManager";
import {t} from "@lingui/macro";
import {BatchToolbarActions} from "./BatchToolbarActions";
import {BatchToolBarBatchInfoList} from "./BatchToolbarBactchInfoList";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {Check, Edit} from "@material-ui/icons";
import {useBatchManagerContext} from "../../hooks/useBatchManagerContext";
import {EditBatchIdDialog} from "./BatchIdEditDialog";
import {useModalHandler} from "../../hooks/useModalHandler";

const useStyles = makeStyles((theme: Theme) => ({
        batchInfoWrapper: {
            flexGrow: 1,
            marginRight: theme.spacing(4)
        },
        lastSaveAtWrapper:{
            color: grey[500],
            marginLeft: theme.spacing(1)
        },
        check: {
            fontSize: '0.75rem',
            marginRight: theme.spacing(0.5)
        },
        batchIdLabel: {
            color: grey[700],
            fontWeight: 'bold'
        },
        saveButton: {
            background: green[600]
        },
        resetButton: {
            background: red[600]
        }
    })
);

export const BatchEditToolbar: React.FunctionComponent = observer(({}) => {
    const classes = useStyles();
    const settings = SystemSettingStore.selectedModel as SystemSettingModel;

    const manager = useBatchManagerContext() as BatchManager;

    const [changeBatchDialogOpen, handleCloseChangeBatchId, handleOpenChangeBatchId] = useModalHandler();

    return (
        <Box mb={1}>
            <PaddedPaper>
                <Grid container justifyContent={'space-between'} alignItems={'center'}>
                    <Grid item className={classes.batchInfoWrapper}>
                        <Grid container>
                            <Typography variant={'h5'} className={classes.batchIdLabel}>{t`Batch ID ${manager.data.batchId}`}</Typography>
                            <Box ml={0.5}>
                                <IconButton size={'small'} onClick={handleOpenChangeBatchId}>
                                    <Edit/>
                                </IconButton>
                                <EditBatchIdDialog open={changeBatchDialogOpen} handleClose={handleCloseChangeBatchId}/>
                            </Box>
                        </Grid>
                        <Box mt={0.5}>
                            <Divider/>
                        </Box>
                        <BatchToolBarBatchInfoList data={manager.batchDisplayInfo}/>
                    </Grid>
                    <Grid item>
                        <BatchToolbarActions/>
                        {settings &&
                            <Grid container alignItems={'center'} className={classes.lastSaveAtWrapper}>
                                <Check className={classes.check}/>
                                <Typography variant={"caption"}>{t`Last successful save at ${settings.printTime(manager.lastSuccessfulSaveTime)}`}</Typography>
                            </Grid>
                        }
                    </Grid>
                </Grid>
            </PaddedPaper>
        </Box>
    )
});

