import * as React from "react";
import {observer} from "mobx-react-lite";
import {
    Box,
    Button,
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    Grid,
    makeStyles,
    Theme, Typography
} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {InputField} from "@rx-suite/ui";
import {useBatchManagerContext} from "../../hooks/useBatchManagerContext";
import {useEffect} from "react";
import {GenerateBatchIdButton} from "./GenerateBatchIdButton";
import {ArBatchManager} from "../../../objects/batch_workstation_manager/ArBatchManager";

type EditBatchIdDialogProps = {
    open: boolean,
    handleClose: () => void
}

const useStyles = makeStyles((theme: Theme) => ({
        inputField: {
            flexGrow: 1
        },
        arWarningText: {
            fontSize: '0.85rem',
            fontWeight: "bold"
        }
    })
);

export const EditBatchIdDialog: React.FunctionComponent<EditBatchIdDialogProps> = observer(({open, handleClose}) => {
    const classes = useStyles();

    const manager = useBatchManagerContext();

    const [tempBatchId, setTempBatchId] = React.useState<string>(manager.data.batchId);

    useEffect(() => {
        setTempBatchId(manager.data.batchId);
    }, [open]) // use open so that everytime the dialog is open, force refresh

    const handleUpdateBatchId = () => {
        manager.setBatchId(tempBatchId as string);
        handleClose();
    }

    return (
        <React.Fragment>
            <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title" fullWidth={true} maxWidth={'xs'}>
                <DialogTitle>
                    <Trans>Edit Batch ID</Trans>
                </DialogTitle>
                <DialogContent>
                    <Box mb={4}>
                        <Grid container alignItems={'center'}>
                            <InputField
                                label={t`Batch ID`}
                                onChange={(e) => setTempBatchId(e.target.value)}
                                value={tempBatchId}
                                className={classes.inputField}
                            />
                            <GenerateBatchIdButton setTempId={setTempBatchId}/>
                        </Grid>
                    </Box>
                    {
                        (manager instanceof ArBatchManager) &&
                        <Typography variant={'subtitle1'} className={classes.arWarningText}>
                            <Trans>Warning: updating the batch ID will also update every sector ID.</Trans>
                        </Typography>
                    }
                </DialogContent>
                <DialogActions>
                    <Button onClick={handleClose} color="secondary" variant={'outlined'}>
                        <Trans>Cancel</Trans>
                    </Button>
                    <Button onClick={handleUpdateBatchId} color="secondary" variant={'contained'} disabled={tempBatchId.trim() === ''}>
                        <Trans>Update</Trans>
                    </Button>
                </DialogActions>
            </Dialog>
        </React.Fragment>
    )
});

