import * as React from "react";
import {observer} from "mobx-react-lite";
import {createStyles, makeStyles, Theme} from "@material-ui/core";
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {ArrowBack, Check} from "@material-ui/icons";
import {useBatchManagerContext} from "../../hooks/useBatchManagerContext";
import {useModalHandler} from "../../hooks/useModalHandler";
import {InformationDialog} from "../dialogs/InformationalDialog";
import {useSnackbar} from "notistack";
import {routerStore} from "@rx-suite/data";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({

    })
);

export const BatchSummaryActions: React.FunctionComponent = observer(() => {

    const {enqueueSnackbar} = useSnackbar();

    const [submitBatchDialogOpen, handleCloseSubmitBatchDialog, handleOpenSubmitBatchDialog] = useModalHandler();
    const [isSubmitting, setIsSubmitting] = React.useState<boolean>(false);

    const manager = useBatchManagerContext();

    const handleBackToBatches = React.useCallback(() => {
        routerStore.history.push('/batches');
    }, []);

    const handleSubmit = React.useCallback(async () => {
        handleCloseSubmitBatchDialog();
        try {
            setIsSubmitting(true);
            await manager.confirmAndFinalizeCurrentBatch();
        }catch (e) {
            console.error(e);
            enqueueSnackbar(`${t`Error while validating batch!`}`, {variant: "error"})
        }
        setIsSubmitting(false);
    }, []);

    if(!manager){
        return (
            <React.Fragment>
                <ButtonField
                    startIcon={<ArrowBack/>}
                    text={t`Back to All Batches`}
                    size={'large'}
                    onClick={handleBackToBatches}
                />
            </React.Fragment>
        )
    }

    return (
        <React.Fragment>
            <ButtonField
                startIcon={<ArrowBack/>}
                text={t`Back to Edit`}
                size={'large'}
                onClick={()=> manager.setShowBatchSummary(false)}
            />
            <ButtonField
                startIcon={<Check/>}
                text={t`Validate and Complete Batch`}
                color={'secondary'}
                loading={isSubmitting}
                size={'large'}
                onClick={handleOpenSubmitBatchDialog}
            />
            <InformationDialog
                message={t`This action will permanently save the current batch. Once the batch is finalized you will not be able to edit it.`}
                open={submitBatchDialogOpen}
                onConfirm={handleSubmit}
                handleClose={handleCloseSubmitBatchDialog}
            />
        </React.Fragment>
    )
});