import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles, Theme} from "@material-ui/core";
import {ButtonField} from "@rx-suite/ui";
import {green} from "@material-ui/core/colors";
import {BatchManager} from "../../../objects/batch_workstation_manager/BatchManager";
import {t} from "@lingui/macro";
import {useBatchManagerContext} from "../../hooks/useBatchManagerContext";

type GenerateBatchIdButtonProps = {
    setTempId: React.Dispatch<React.SetStateAction<string>>;
}

const useStyles = makeStyles((theme: Theme) => ({
        button: {
            backgroundColor: green[600]
        }
    })
);

export const GenerateBatchIdButton: React.FunctionComponent<GenerateBatchIdButtonProps> = observer(({setTempId}) => {
    const classes = useStyles();

    const manager = useBatchManagerContext() as BatchManager;

    const handleGenerateBatchId = React.useCallback(() => {
        setTempId(manager.getNewBatchId());
    }, []);

    return (
        <ButtonField
            text={t`Generate`}
            variant={'contained'}
            className={classes.button}
            onClick={handleGenerateBatchId}
        />
    )
});

