import * as React from 'react';
import {observer} from 'mobx-react-lite';
import Delete from '@material-ui/icons/Delete';
import {t} from '@lingui/macro';
import {CircularProgress, makeStyles} from '@material-ui/core';
import {useSnackbar} from "notistack";
import {errToString} from "@rx-suite/data";
import {ModelTableActionButtonProps, ModelTableButton} from "@rx-suite/ui";

const useStyles = makeStyles(theme => ({
    danger: {
        color: theme.palette.error.main
    }
}));

export const CustomDeleteButton: React.FunctionComponent<ModelTableActionButtonProps> = observer(({
                                                                                                          store,
                                                                                                          model
                                                                                                      }) => {
    const {enqueueSnackbar} = useSnackbar();
    const handleClick = React.useCallback(async () => {
        try {
            await model.delete(t`Are you sure you want to delete?`);
        } catch (e) {
            enqueueSnackbar(t`Problem deleting:` + errToString(e), {variant: 'error'});
        }
    }, [enqueueSnackbar, model]);
    const classes = useStyles();
    return (
        <ModelTableButton
            verb="delete"
            onClick={handleClick}
            disabled={!model.isUserDeletable || model.updating || !model.canDelete()}
            store={store}
        >
            {model.updating ? <CircularProgress size={24}/> :
                <Delete className={(model.isUserDeletable && model.canDelete()) ? classes.danger : undefined}/>}
        </ModelTableButton>
    )
});