import {action, computed, makeObservable, observable} from "mobx";
import {LensSide} from "../batch_workstation_manager/BatchManager";

export class LensDatum {
    @observable
    public jobInfo: LensJobInfo | null;

    @observable
    public skipped: boolean;

    public readonly position: number;

    constructor(data: SerializedLensDatum) {
        makeObservable(this);

        this.position = data.position;
        this.jobInfo = data.jobInfo;
        this.skipped = data.skipped;
    }

    public serialize(): SerializedLensDatum {
        return {
            position: this.position,
            jobInfo: this.jobInfo,
            skipped: this.skipped
        }
    }

    @computed
    public get isAvailable(): boolean {
        return this.jobInfo == null && !this.skipped
    }

    @action
    public clear(): void {
        this.jobInfo = null;
        this.skipped = false;
    }

    @action
    public skip(): void {
        if(this.skipped || this.jobInfo !== null){
            return;
        }

        this.skipped = true;
    }
}

export type LensJobInfo = {
    jobNumber: string;
    side: LensSide;
};

export type SerializedLensDatum = {
    position: number;
    jobInfo: LensJobInfo | null;
    skipped: boolean;
}