import {CanvasRenderer} from "../CanvasRenderer";
import {darken} from "@material-ui/core";
import {blue} from "@material-ui/core/colors";

export class ArDomeSectorPositionRenderer extends CanvasRenderer {
   private readonly numberOfSectors: number;
   private readonly highlightedSector: number;
   private readonly size: number;

    constructor(size: number, numberOfSectors: number, highlightedSector: number) {
        super();
        this.numberOfSectors = numberOfSectors <= 0 ? 1 : numberOfSectors;
        this.highlightedSector = highlightedSector;
        this.size = size;
    }

    protected handleDraw(): void {
        const sectorSize = (2 * Math.PI) / this.numberOfSectors;
        const startPoint = (this.highlightedSector * ((2 * Math.PI) / this.numberOfSectors)) - (0.5 * Math.PI);

        this.drawPartialCircle(0, 2 * Math.PI, this.size,{fillColor: 'lightgray'});

        for(let i = 0; i < this.numberOfSectors; i++){
            this.drawPartialCircle(startPoint + (i * sectorSize), sectorSize, this.size, { strokeColor: 'white', lineWidth: 4});
        }

        this.drawPartialCircle(startPoint, sectorSize, this.size, {fillColor: darken(blue[900], 0.15)});
    }

    protected afterSetLayout(): void {
        // Nothing to do here in edit mode
    }

}