import {CanvasRenderer} from "../CanvasRenderer";
import {BatchContainerComponentModel} from "../../../stores/BatchContainerComponentStore";
import {blue, grey, orange} from "@material-ui/core/colors";
import {darken} from "@material-ui/core";
import {action} from "mobx";

export class BatchContainerViewRenderer extends CanvasRenderer {
    private positionStates : BatchContainerPositionStates;

    constructor() {
        super();

        this.positionStates = {
            focused: [],
            skipped: [],
            completed: [],
        }
    }

    @action
    protected handleDraw(): void {
        // Use the view model to render the positions
        this.ensureComponentsPositionData();

        this.layout.current_ordered_component.forEach(c => {
            switch (c.component_type) {
                case 'batch_position':
                    this.drawBatchPosition(c);
                    break;
                case 'batch_image':
                    this.drawImage(c);
                    break;
            }
        });
    }

    public setPositionStates(positionData: BatchContainerPositionStates){
        this.positionStates = positionData;

        this.draw();
    }

    protected afterSetLayout(): void {
        // Nothing to do here in edit mode
    }

    protected drawBatchPosition(c: BatchContainerComponentModel): void {
        const positionInBatch = c.position as number

        let color = 'black'
        if(this.positionStates.focused.indexOf(positionInBatch) !== -1){
            color = orange[300];
        }else if(this.positionStates.skipped.indexOf(positionInBatch) !== -1){
            color = grey[600];
        }else  if(this.positionStates.completed.indexOf(positionInBatch) !== -1){
            color = darken(blue[900], 0.15);
        }

        this.drawOval({x: c.x, y: c.y},  c.width/2, c.height/2, {fillColor: color});
        this.drawText(positionInBatch.toString(), {x: c.x + (c.width/2), y: c.y + (c.height/2) })
    }

    @action
    protected ensureComponentsPositionData(): void {
        // When data is manually changed via the input field, the component can end up with strings
        for(let component of this.layout.components){
            component.viewModel.x = ensurePositive(Number(component.viewModel.x));
            component.viewModel.y = ensurePositive(Number(component.viewModel.y));
            component.viewModel.z_index = Number(component.viewModel.z_index);
            component.viewModel.height = Number(component.viewModel.height);
            component.viewModel.width = Number(component.viewModel.width);
        }
    }

    public static readonly BATCH_CONTAINER_CANVAS_WIDTH = 1280;
    public static readonly BATCH_CONTAINER_CANVAS_HEIGHT = 720;

    public static readonly BATCH_POSITION_MIN_WIDTH = 50;
    public static readonly BATCH_POSITION_MIN_HEIGHT = 50;
}

function ensurePositive(val: number){
    return val > 0 ? val : 0;
}

export type BatchContainerPositionStates = {
    focused: number[];
    skipped: number[];
    completed: number[];
}