import * as React from "react";
import {ButtonField, FormProps, ModelForm, ModelInput, PaddedPaper} from "@rx-suite/ui";
import {makeStyles, Grid, Container} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import {BatchContainerModel} from "../../stores/BatchContainerStore";
import {BatchConfigComponentDetails} from "../../components/batch_container/edit_controls/BatchConfigComponentDetails";
import {BatchContainerEditControls} from "../../components/batch_container/edit_controls/BatchContainerEditControls";
import {BatchContainerEditCanvas} from "../../components/batch_container/BatchContainerEditCanvas";
import {BatchProcessCode} from "../../stores/BatchProcessStore";
import {t} from "@lingui/macro";
import {ArrowBack} from "@material-ui/icons";
import {BatchContainerEditRenderer} from "../../objects/canvas_renderer/batch_container/BatchContainerEditRenderer";

type BatchContainerFormProps = {
    model: BatchContainerModel;
    setContainer: (container: BatchContainerModel | null) => void;
    getProcessInfo: () => {
        id: number;
        process_code: BatchProcessCode;
    };
} & Omit<FormProps, 'model'>

const useStyles = makeStyles({
    sectorWrap: {
        width: '47rem',
        height: '35rem'
    }
});

export const BatchContainerForm: React.FunctionComponent<BatchContainerFormProps> = observer(({model, setContainer, getProcessInfo}) => {

    const classes = useStyles();

    if (!model.batch_process_id) {
        model.batch_process_id = getProcessInfo().id;
    }

    const [canvasRenderer] = React.useState<BatchContainerEditRenderer>(new BatchContainerEditRenderer());

    return (
        <Container maxWidth={'lg'}>
            <PaddedPaper>
                <ButtonField
                    startIcon={<ArrowBack/>}
                    text={t`Back to Process`}
                    variant={'contained'}
                    color={'primary'}
                    onClick={() => { setContainer(null); }}
                />
                <ModelForm
                    model={model}
                    afterSubmit={() => { setContainer(null); }}
                    suppressRedirect
                    suppressMakeCopy
                    suppressImportExport
                    suppressWrapper
                >
                    <ModelInput name={"name"}/>
                    <BatchContainerEditControls renderer={canvasRenderer}/>
                    <Grid container justifyContent={'space-evenly'}>
                        <Grid item>
                            <div className={classes.sectorWrap}>
                                <BatchContainerEditCanvas container={model} renderer={canvasRenderer}/>
                            </div>
                        </Grid>
                        <Grid item>
                            <BatchConfigComponentDetails renderer={canvasRenderer}/>
                        </Grid>
                    </Grid>
                </ModelForm>
            </PaddedPaper>
        </Container>
    );
});
