import * as React from "react";
import {PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Trans} from "@lingui/macro";
import {SectorTemplatesTable} from "./SectorTemplatesTable";
import {BatchProcessModel} from "../../../stores/BatchProcessStore";
import {BatchContainerModel, BatchContainerStore} from "../../../stores/BatchContainerStore";
import {BatchContainerForm} from "../../batch_container/BatchContainerForm";
import {Box, Container, Divider, Typography} from "@material-ui/core";

type BatchProcessFormProps = {
  model: BatchProcessModel;
};

export const ArCoatingProcessForm: React.FunctionComponent<BatchProcessFormProps> = observer(({model}) => {
    const [currentContainer, setCurrentContainer] = React.useState<BatchContainerModel | null>(null);

    const filteredContainerModels = BatchContainerStore.getAll().filter((bc) => { return bc.batch_process_id === model.id; });

    const getModelInfo = () => {
        return {
            id: model.id as number,
            process_code: model.batch_process_code
        };
    };

    if (currentContainer) {
        return <BatchContainerForm model={currentContainer} setContainer={setCurrentContainer} getProcessInfo={getModelInfo}/>;
    }

    return (
        <Container maxWidth={'lg'}>
            <PaddedPaper>
                <Typography variant={'h4'}>
                    <Trans>
                        AR Coating Settings
                    </Trans>
                </Typography>
                <Box mt={1} mb={1}>
                    <Divider/>
                </Box>
                <SectorTemplatesTable containers={filteredContainerModels} setContainer={setCurrentContainer}/>
            </PaddedPaper>
        </Container>
    );
});
