import * as React from 'react';
import {t} from "@lingui/macro";
import {BatchContainerModel, BatchContainerStore} from "../../../stores/BatchContainerStore";
import {CustomReadButton} from "../../../components/generic/model_custom_action_buttons/CustomReadButton";
import {CustomEditButton} from "../../../components/generic/model_custom_action_buttons/CustomEditButton";
import {CustomDeleteButton} from "../../../components/generic/model_custom_action_buttons/CustomDeleteButton";
import {currentUserCan} from "@rx-suite/stores";
import {Typography} from "@material-ui/core";
import ReactTable from "react-table";
import {ButtonField} from "@rx-suite/ui";
import {Add} from "@material-ui/icons";
import {BatchContainerViewCanvas} from "../../../components/batch_container/BatchContainerViewCanvas";
import {useEffect} from "react";
import {LoaderWithText} from "../../../components/generic/LoaderWithText";

type BatchContainerBreadModelProps = {
    containers: Array<BatchContainerModel>;
    setContainer: (container: BatchContainerModel) => void;
};

export const SectorTemplatesTable: React.FunctionComponent<BatchContainerBreadModelProps> = ({containers, setContainer}) => {
    useEffect(() => {
       containers.forEach(container => container.fetchFullModel());
    }, [containers])

    if(containers.some(container => !container.loaded_full_model)){
        return <LoaderWithText message={t`Loading Sector Templates`}/>;
    }

    const columns = [
        {
            Header: t`Name`,
            accessor: 'name'
        },
        {
            Header: t`Holes in Sector`,
            minWidth: 35,
            accessor: (containerModel: BatchContainerModel) => containerModel,
            id: 'lens_count',
            Cell: (cellInfo: { value: BatchContainerModel }) => {
                const model = cellInfo.value;

                if (!model || !model.getId) {
                    return null;
                }
                return <>
                   <Typography variant={'body1'}>{model.component_count}</Typography>
                </>
            }
        },
        {
            Header: t`Sector Preview`,
            id: 'container_image',
            sortable: false,
            accessor: (containerModel: BatchContainerModel) => containerModel,
            Cell: (cellInfo: { index: number, value: BatchContainerModel }) => {
                return <BatchContainerViewCanvas model={cellInfo.value}/>
            }
        },
        {
            accessor: (containerModel: BatchContainerModel) => containerModel,
            id: '_actions',
            style: {textAlign: "right"},
            minWidth: 35,
            Cell: (cellInfo: { value: BatchContainerModel }) => {

                const store = BatchContainerStore;
                const model = cellInfo.value;

                if (!model || !model.getId) {
                    return null;
                }
                return <>
                    <CustomReadButton store={store} model={model} onClick={() => { setContainer(model) }}/>
                    <CustomEditButton store={store} model={model} onClick={() => { setContainer(model) }}/>
                    <CustomDeleteButton store={store} model={model}/>
                </>
            }
        }
    ];

    const createLink = BatchContainerStore.createLink();
    const canCreate = !BatchContainerStore.permissionTarget || currentUserCan(BatchContainerStore.permissionTarget, 'create');

    const createNewContainer = () => {
        setContainer(BatchContainerStore.createModel());
    };

    return (<>
        {createLink !== null && canCreate &&
            <ButtonField
                startIcon={<Add/>}
                text={t`Add Sector Template`}
                onClick={createNewContainer}
                style={{marginBottom: '1rem'}}
                variant={'contained'}
                color={'secondary'}
            />
        }
        <ReactTable
            data={containers}
            columns={columns}
            minRows={10}
            defaultPageSize={10}
            defaultSorted={[{ id: 'name', desc: false}]}
        />
    </>);
};