import * as React from "react";
import {observer} from "mobx-react-lite";
import {BatchModel} from "../../stores/BatchStore";
import {BatchData} from "../../stores/BatchWorkstationStore";
import {Alert} from "@material-ui/lab";
import {t, Trans} from "@lingui/macro";
import {LoaderWithText} from "../../components/generic/LoaderWithText";
import {ArBatchSummary} from "../../components/ar_coating/workstation/forms/ArBatchSummary";

type BatchProcessFormProps = {
    model: BatchModel;
};

export const BatchViewForm: React.FunctionComponent<BatchProcessFormProps> = observer(({model}) => {

   const [batchData, setBatchData] = React.useState<BatchData | null>(null);

    React.useEffect(() => {
        (async () => {
           setBatchData(await model.getRxDataBatch()) ;
        })();
    }, []);

    if(!batchData){
        return (
            <LoaderWithText message={t`Loading batch data...`}/>
        );
    }

    switch(batchData.processCode){
        case 'ar_coating':
            return <ArBatchSummary data={batchData}/>;
    }

    return (
        <Alert severity={'error'}>
            <Trans>Something went wrong while loading this batch data. Please try refreshing the page or contact support.</Trans>
        </Alert>
    )
});