import * as React from "react";
import {BreadModel, makeColumn, makeFormattedDateTimeColumn, SelectField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {observer} from "mobx-react-lite";
import {BatchModel, BatchStore} from "../../stores/BatchStore";
import {BatchViewForm} from "./BatchViewForm";
import {Filter, ReactTableFunction} from "react-table";
import {BatchProcessStore} from "../../stores/BatchProcessStore";

export const BatchesBreadModel = observer(() => {
    BatchProcessStore.getAll();

    const processOptions =  React.useMemo(() => {
        return BatchProcessStore.models.map((process) => {
            return {label: process.name, value: process.batch_process_code}
        });
    }, [BatchProcessStore.models])

    const columns = React.useMemo(() => {
        return [
            makeFormattedDateTimeColumn('created_at', t`Created At`, "dateTime"),
            {
                Header: t`Process`,
                id: 'process_code',
                accessor: (batch: BatchModel) => batch,
                Cell: (cellInfo: {value: BatchModel }) => {
                    const process = BatchProcessStore.models.find(model => model.batch_process_code == cellInfo.value.process_code)

                    if(process){
                        return process.name;
                    }

                    return cellInfo.value.process_code
                },
                filterable: true,
                Filter: ({ filter, onChange }: { filter: Filter, onChange: ReactTableFunction})=> (
                    <SelectField
                        options={processOptions}
                        onChange={(name, value) => onChange(value)}
                        value={filter ? filter.value : ""}
                    />
                )
            },
            makeColumn('batch_id', t`Batch ID`, "string"),
        ];
    }, [BatchProcessStore.models]);

    return(
        <BreadModel
            store={BatchStore}
            Form={BatchViewForm}
            columns={columns}
            defaultSorted={[{id: 'created_at', desc: true}]}
        />
    )
});