import * as React from "react";
import {t, Trans} from "@lingui/macro"
import {OperatorScannerField} from "../../components/generic/OperatorScannerField";
import {getBatchByJobNumber} from "../../stores/BatchStore";
import {Container, makeStyles, Typography} from "@material-ui/core";
import {PaddedPaper, SelectField} from "@rx-suite/ui";
import {BatchProcessStore} from "../../stores/BatchProcessStore";
import {useSnackbar} from "notistack";
import {routerStore} from "@rx-suite/data";
import {useBatchingProcessOptions} from "../../components/hooks/useBatchingProcessOptions";

const useStyles = makeStyles((theme) => ({
    searchFields: {
        marginTop: '2rem'
    },
    scannerField: {
        marginTop: '1rem'
    }
}));

export const SearchBatchByJobNumber = () => {

    const classes = useStyles();

    const {enqueueSnackbar} = useSnackbar();

    const [processId, setProcessId] = React.useState<number | null>(null);

    const processOptions = React.useMemo(()=> {
        return useBatchingProcessOptions();
    }, [BatchProcessStore.models]);

    const searchBatch = React.useCallback(async (searchVal: string) => {
        if (processId == null) return; // should never be hit since displaying the job search means a processId is selected

        const batchData = await getBatchByJobNumber(processId, searchVal);

        if ('error' in batchData) {
            enqueueSnackbar(`${t`Error: ${batchData.error}`}`, {variant: "error"});
            return;
        }

        routerStore.history.push(`/batches/${batchData.batchId}/edit`);

    }, [processId]);

    return (
        <Container maxWidth={"md"}>
            <PaddedPaper>
                <Typography variant={'h4'}>
                    <Trans>Find Batch by Job Number</Trans>
                </Typography>
                <div className={classes.searchFields}>
                    <SelectField
                        label={t`Process Code`}
                        onChange={(name, value) => { setProcessId(value); }}
                        value={processId}
                        options={processOptions}
                    />
                    {processId && <div className={classes.scannerField}>
                        <OperatorScannerField
                            searchFieldPlaceHolderText={t`Job Number`}
                            searchFunction={searchBatch}
                        />
                    </div>}
                </div>
            </PaddedPaper>
        </Container>
    )
};
