import * as React from "react";
import {BreadModel, makeColumn, SelectField} from "@rx-suite/ui";
import {BatchWorkstationModel, BatchWorkstationStore} from "../../stores/BatchWorkstationStore";
import {t} from "@lingui/macro";
import {observer} from "mobx-react-lite";
import {BatchWorkstationForm} from "./BatchWorkstationForm";
import {Filter, ReactTableFunction} from "react-table";
import {BatchProcessStore} from "../../stores/BatchProcessStore";
import {useBatchingProcessOptions} from "../../components/hooks/useBatchingProcessOptions";

export const BatchWorkstationBreadModel = observer(() => {
    const columns = React.useMemo(() => {
        return [
            makeColumn('name', t`Workstation Name`, 'string'),
            {
                Header: t`Process`,
                accessor: (workstation: BatchWorkstationModel) => workstation,
                id: 'batch_process_id',
                Cell: (cellInfo: { value: BatchWorkstationModel }) => {
                    const process = BatchProcessStore.models.find(process => process.getId() === (cellInfo.value.batch_process_id as unknown as string));

                    if(!process){
                        return null;
                    }

                    return process.name;
                },
                filterable: true,
                Filter: ({filter, onChange}: { filter: Filter, onChange: ReactTableFunction }) => (
                    <SelectField
                        options={useBatchingProcessOptions()}
                        onChange={(name, value) => onChange(value)}
                        value={filter ? filter.value : ""}
                    />
                )
            }
        ]
    }, [BatchProcessStore.models]);

    return (
        <BreadModel store={BatchWorkstationStore} Form={BatchWorkstationForm} columns={columns} />
    )
});