import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {BatchManagerProvider} from "../../../components/hooks/useBatchManagerContext";
import {BatchingWorkstationFormRouter} from "./BatchingWorkstationFormRouter";
import {BatchProcessStore} from "../../../stores/BatchProcessStore";
import {ArBatchManager} from "../../../objects/batch_workstation_manager/ArBatchManager";
import {useEffect} from "react";
import {BatchData, BatchWorkstationModel} from "../../../stores/BatchWorkstationStore";
import {LoaderWithText} from "../../../components/generic/LoaderWithText";

type BatchingWorkstationProps = {
    workstation: BatchWorkstationModel;
};

export const BatchingWorkstation: React.FunctionComponent<BatchingWorkstationProps> = observer(({workstation}) => {
    const process = BatchProcessStore.models.find(p => p.getId() === (workstation.batch_process_id as unknown as string))

    const [manager, setManager] = React.useState<undefined | ArBatchManager>(undefined);

    useEffect(() => {
        (async() => {
            if(!process){
                return;
            }

            // We need this hook to fire a second time to properly hook up the auto save release so if the
            // manager is already set, ignore the second call except to set the clear interval callback
            if(manager){
                return;
            }

            const batchData = await workstation.loadCurrentBatchData() as BatchData | null;

            switch (process.batch_process_code){
                case 'ar_coating':
                    setManager(new ArBatchManager(workstation, batchData));
                    break;
                default:
                    throw `Invalid process ${process.batch_process_code}!`;
            }
        })();

        return () => {
            if(manager){
                manager.stopAutoSave();
            }
        }
    }, [process, manager]);

    if(!process || !manager){
        return (<LoaderWithText message={t`Loading Workstation Handler...`}/>);
    }

    return (
        <BatchManagerProvider value={manager}>
            <BatchingWorkstationFormRouter/>
        </BatchManagerProvider>
    )
});
