import React from "react";
import {computedFn} from "mobx-utils";
import {dataStorePermission} from "@rx-suite/ui";
import {
    AssignmentReturned,
    Devices,
    GroupWork,
    Search,
    Settings,
    SubdirectoryArrowRight,
    Tune
} from '@material-ui/icons';
import {BatchProcessStore} from "./stores/BatchProcessStore";
import {t} from "@lingui/macro";
import {BatchWorkstationStore} from "./stores/BatchWorkstationStore";
import {BatchWorkstationBreadModel} from "./pages/batch_workstations/BatchWorkstationBreadModel";
import {ArCoatingProcessForm} from "./pages/batch_process/ar_coating/ArCoatingProcessForm";
import {currentUserCanModule} from "@rx-suite/stores";
import {BatchesBreadModel} from "./pages/batch_search/BatchesBreadModel";
import {SearchBatchByJobNumber} from "./pages/batch_search/SearchBatchByJobNumber";
import {BatchingWorkstation} from "./pages/batch_workstations/workstation/BatchingWorkstation";


export const getRoutes = computedFn(() => {
    const arCoatingProcess = BatchProcessStore.getAll().find(process => process.batch_process_code === 'ar_coating');

    let batchCoatingWorkstations = [];

    if(arCoatingProcess){
        batchCoatingWorkstations = BatchWorkstationStore.getAll().filter(workstation => workstation.batch_process_id == arCoatingProcess.getId());
    }

    return [
        {
            to: "/",
            exact: false,
            shouldMount: () => currentUserCanModule('Batch', 'read', 'rx_data'),
            Component: BatchesBreadModel,
        },
        {
            label: t`AR Coating`,
            to: "/ar_workstations",
            exact: false,
            Icon: GroupWork,
            shouldMount: () => batchCoatingWorkstations.length > 0,
            children: batchCoatingWorkstations.map( workstation => (
                    {
                        label: workstation.name,
                        to: `/${workstation.id}`,
                        permission: {
                            target: `batch_workstation_${workstation.id}`,
                            action: 'use'
                        },
                        exact: false,
                        Icon: SubdirectoryArrowRight,
                        Component: () => <BatchingWorkstation workstation={workstation}/>
                    }
                ))
        },
        {
            label: t`Search Batches`,
            to: "",
            exact: false,
            shouldMount: () => currentUserCanModule('Batch', 'read', 'rx_data'),
            Icon: Search,
            children: [
                {
                    label: t`All Batches`,
                    to: "/batches",
                    exact: false,
                    Component: BatchesBreadModel,
                    Icon: SubdirectoryArrowRight
                },
                {
                    label: t`Search by Job`,
                    to: "/search_by_job",
                    exact: false,
                    Component: SearchBatchByJobNumber,
                    Icon: SubdirectoryArrowRight
                },
            ]
        },
        {
            label: t`Settings`,
            to: "",
            exact: false,
            Icon: Settings,
            children: [
                {
                    label: "Processes",
                    to: "/processes",
                    exact: false,
                    permission: dataStorePermission(BatchProcessStore),
                    Icon: AssignmentReturned,
                    children: [
                        {
                            label: "AR Coating",
                            to: `/ar_coating`,
                            exact: false,
                            permission: dataStorePermission(BatchProcessStore),
                            Component: ArCoatingProcessForm,
                            props: {model: arCoatingProcess},
                            Icon: GroupWork
                        }
                    ]
                },
                {
                    label: "Workstations",
                    to: "/batch_workstations",
                    exact: false,
                    permission: dataStorePermission(BatchWorkstationStore),
                    Component: BatchWorkstationBreadModel,
                    Icon: Devices
                }
            ]
        }
    ]});
