import {attribute, DataStore, Model, model} from '@rx-suite/data';
import {computed, observable} from "mobx";
import {CanvasComponentPosition} from "../objects/canvas_renderer/CanvasRenderer";
import {t} from "@lingui/macro";
import * as yup from "yup";

@model({})

export class BatchContainerComponentModel extends Model {
    @attribute()
    id: number = -1;

    @computed
    get name(): string {
        if(this.component_type === 'batch_position'){
            return `Position ${this.position}`
        }
        else{
            return `Container Image`;
        }
    }

    @attribute()
    component_type: ComponentType = 'batch_position';

    @attribute()
    batch_container_id = 0;

    @attribute()
    position: number | null = 0;

    @attribute({
        label: t`X`,
        validation: yup.number()
    })
    x: number = 0.0;

    @attribute({
        label: t`Y`,
        validation: yup.number()
    })
    y: number = 0.0;

    @attribute({
        label: t`Height`,
        validation: yup.number()
    })
    height: number = 75;

    @attribute({
        label: t`Width`,
        validation: yup.number()
    })
    width: number = 75;

    @attribute()
    z_index = 0;

    @attribute()
    aspect_ratio = 1;

    @attribute({
        validation: yup.string().nullable()
    })
    image_url: string | null = null;
    @observable file: Blob | undefined;
    @observable image: CanvasImageSource | undefined;

    @computed
    get isBatchPosition(): boolean {
        return this.component_type === 'batch_position';
    }

    @computed
    get isBatchImage(): boolean {
        return this.component_type === 'batch_image';
    }

    @computed
    get canvas_position(): CanvasComponentPosition {
        return {x: this.x, y: this.y};
    }

    pointOverlapsComponentCorner(point: CanvasComponentPosition): boolean {
        return Math.abs(this.x - point.x) < this.width &&
            Math.abs(this.x - point.x) > (this.width - 20) &&
            Math.abs(this.y - point.y) < this.height &&
            Math.abs(this.y - point.y) > (this.height - 20)
    }
    pointOverlapsComponentBottom(point: CanvasComponentPosition): boolean {
        return Math.abs(this.y - point.y) < this.height &&
               Math.abs(this.y - point.y) > (this.height - 15)
    }
    pointOverlapsComponentSide(point: CanvasComponentPosition): boolean {
        return Math.abs(this.x - point.x) < this.width &&
            Math.abs(this.x - point.x) > (this.width - 15)
    }

    pointOverlapsComponent(point: CanvasComponentPosition): boolean {
        return point.x > this.x &&
            point.x < (this.x + this.width) &&
            point.y > this.y &&
            point.y < (this.y + this.height)
    }

    constructor() {
        super();
        super.setup();
    }
}

export type ComponentType = 'batch_position' | 'batch_image'

export const BatchContainerComponentStore = BatchContainerComponentModel.store as DataStore<BatchContainerComponentModel>;