import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro";

export const BatchProcessCodes = ['ar_coating'];
export type BatchProcessCode = typeof BatchProcessCodes[number];

@model({
    transportLayer: "/api/batch_processes",
        permissionTarget: "BatchProcess",
        routingInfo: {
            create: '/batch_processes/create',
            read: '/batch_processes/:id/edit',
            update: '/batch_processes/:id/edit'
        },
        eager: true
})

export class BatchProcessModel extends Model {

    @attribute({
        label: t`Name`,
        validation: yup.string()
    })
    name: string = '';

    @attribute({
        label: t`Batch Process Code`,
        validation: yup.string().required()
    })
    batch_process_code: BatchProcessCode = 'ar_coating';

    @attribute({
        label: t`Batch Template Ids`,
        validation: yup.array()
    })
    batch_template_ids: Array<number> = [];

    @attribute({
        label: t`Batch Container Ids`,
        validation: yup.array()
    })
    batch_container_ids: Array<number> = [];

    constructor() {
        super();
        super.setup();
    }
}

export const BatchProcessStore = BatchProcessModel.store as DataStore<BatchProcessModel>;