import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import {t} from "@lingui/macro";

@model({
    transportLayer: "/api/users",
    permissionTarget: "User",
    routingInfo: {
        create: '/users/create',
        read: '/users/:id/edit',
        update: '/users/:id/edit'
    }
})
export class UserModel extends Model {
    constructor() {
        super();
        super.setup();
    }

    @attribute({
        label: t`Name`,
        validation: yup.string().required(t`Username is a required field`)
    })
    name = '';

    @attribute({
        label: t`Email`,
        validation: yup.string().email()
    })
    email = '';

    @attribute({
        label: t`Role ID`,
        connects: 'RoleModel',
        validation: yup.number().required(t`Role is a required field`),
    })
    role_id: number | undefined = undefined;
}

export const UserStore = UserModel.store as DataStore<UserModel>;
