class BatchContainer < ApplicationRecord
  has_many :batch_container_batch_workstations, dependent: :destroy
  has_many :batch_workstations, through: :batch_container_batch_workstations

  has_many :batch_container_components, autosave: true , dependent: :destroy

  belongs_to :batch_process

  def update_components(components, files)
    remove_deleted_components(components)
    components.each do |c|
      if new_component?(c)
        comp = batch_container_components.build(component_type: c[:component_type])
      else
        comp = batch_container_components.detect { |component| component.id == c[:id] }
      end

      next if comp.nil?

      comp.assign_attributes({
                                width: c[:width],
                                height: c[:height],
                                x: c[:x],
                                y: c[:y],
                                aspect_ratio: c[:aspect_ratio],
                                z_index: c[:z_index]
                             })

      if comp.is_batch_position?
        comp.assign_attributes({
                                 position: c[:position]
                               })
      elsif comp.is_batch_image?
        file = files['container_image']
        comp.component_image.attach(io: file, filename: File.basename(file.path), content_type: file.content_type, identify: false) unless file.blank?
      end
    end
  end

  def to_json(*_args)
    render_jbuilder_partial
  end

  private

  def remove_deleted_components(components)
    batch_container_components.each do |c|
      keep = components.detect { |comp| c.id == comp[:id] }
      unless keep
        c.mark_for_destruction
      end
    end
  end

  def new_component?(component)
    component[:id] == -1
  end
end
