class BatchWorkstation < ApplicationRecord
  belongs_to :batch_process

  has_one :batch_workstation_current_batch
  has_many :batch_container_batch_workstations, dependent: :destroy
  has_many :batch_containers, through: :batch_container_batch_workstations

  enum data_source: [:lms, :rx_data]
  enum state: [:editing, :saving, :error, :completed]

  def fetch_tags_for_job(job_number)
    if data_source == 'rx_data'
      raise NotImplementedError # Disabled until implemented
    else
      return workstation_error("DCS connection not configured. Please check settings.") if external_dcs_id.nil?

      begin
        RxModule::Communicator.call_module_method_as_module(
          "rx_link",
          "/api/dcs_configs/#{external_dcs_id}/job_call",
          :post,
          {
            job_call:
              {
                job: job_number,
                tags: []
              }
          }
        )
      rescue => err
        workstation_error(err)
      end
    end
  end

  def to_json(*args)
    render_jbuilder_partial
  end

  private

  def workstation_error(error)
    {
      error: {
        message: "An issue occurred while calling fetching data from Rx-Link: #{error}"
      }
    }
  end
end